;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "persp-mode" "20250830.955"
  "Windows/buffers sets shared among frames + save/load."
  '((emacs "24.3"))
  :url "https://github.com/Bad-ptr/persp-mode.el"
  :commit "fab4bf76927445d2e431f06e74572acba81f47d5"
  :revdesc "fab4bf769274"
  :keywords '("perspectives" "session" "workspace" "persistence" "windows" "buffers" "convenience")
  :authors '(("Constantin Kulikov" . "zxnotdead@gmail.com"))
  :maintainers '(("Constantin Kulikov" . "zxnotdead@gmail.com")))
